from __future__ import annotations

import requests

from osdu_client.exceptions import OSDUAPIError
from osdu_client.services.base import OSDUAPIClient
from osdu_client.utils import urljoin


class NotificationAPIError(OSDUAPIError):
    pass


class NotificationClient(OSDUAPIClient):
    service_path = "/api/notification/v1"

    def record_changed(self, data_partition_id: str | None = None) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id

        url = urljoin(self.base_url, self.service_path, "push-handlers/records-changed")
        response = requests.post(url, headers=headers)
        if not response.ok:
            raise NotificationAPIError(response.text, response.status_code)
        return response.json()

    def get_info(self, data_partition_id: str | None = None) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id

        url = urljoin(self.base_url, self.service_path, "info")
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise NotificationAPIError(response.text, response.status_code)
        return response.json()
